@@ -3,7 +3,6 @@
 #   Created on 2/18/2022
 #
 
-import csv
 import os
 from pathlib import Path
 
@@ -15,7 +14,6 @@ from indxdatalaketools.ArgumentValidation import FileMetadata
 from indxdatalaketools.ArgumentValidation import ValidationHelpers
 from indxdatalaketools.GoogleClients.GoogleClients import GcpClients
 from indxdatalaketools.PropertiesDBApi import Properties
-from pyrsistent import b
 
 DOES_NOT_EXIST_BAD_REQUEST = " does not exist: Bad Request"
 
@@ -242,7 +240,7 @@ class Validator():
             Returns:    
                 boolean: True if the blob exists, False if otherwise
         '''
-        file_path = gcs_gsutil_uri.replace("gs://", "")
+        file_path = gcs_gsutil_uri.replace("gs://", "").replace("\"", "")
         bucket_name = file_path.split("/")[0]
         source_blob_name = file_path.split("/", 1)[1]
         bucket = GcpClients.instance().get_storage_client().bucket(bucket_name)
@@ -350,9 +348,8 @@ class Validator():
                 'file_metadata': file_list[i][metadata_index],
                 'file_path': file_list[i][file_path_index]
             }
-
             if not self.validate_all_arguments(arguments, 'file'):
-                Helpers.print_error('Problem on line ' + str(i))
+                Helpers.print_error('Problem on line ' + str(i + 1))
                 return False
 
         # no problems
