@@ -4,6 +4,8 @@
 #
 
 import datetime
+import time
+from indxdatalaketools import DataLakeGlobals
 from indxdatalaketools.GoogleClients.GoogleClients import GcpClients
 from indxdatalaketools.PropertiesDBApi import Properties
 from indxdatalaketools.ArgumentValidation import Argument
@@ -38,6 +40,9 @@ class Client:
         GcpClients.instance(credential_file=credentials_file_path)
         self.__client_ops_logger = GcpClients.instance().get_logging_client(
         ).logger(client_uuid + '-file-logger')
+        if self.client_uuid == 'indx-test-client-datalake':
+            self.__throughput_logger = GcpClients.instance().get_logging_client(
+            ).logger(client_uuid + '-throughput')
         self.__argument_validator = Argument.Validator()
         self.__document_classifier = DocumentClassifierApi.DocClassifierClient()
 
@@ -86,6 +91,7 @@ class Client:
         arguments = {'client_id': self.client_uuid, 'batch_file': file_path}
         data_lake_command = 'file'
 
+        start = time.time()
         Properties.Properties.instance()
 
         if not self.__argument_validator.validate_all_arguments(
@@ -93,6 +99,39 @@ class Client:
             return False
 
         list_of_files = Helpers.read_batch_file(file_path)
+
+        if self.client_uuid == 'indx-test-client-datalake':
+            finish = time.time()
+            upload_time = finish - start
+            self.__throughput_logger.log_text(
+                "It took " + str(upload_time) + " seconds to validate " +
+                str(len(list_of_files) - 1) + " records",
+                severity="INFO")
+
+        failed_uploads = self.__upload_files_from_list(list_of_files, start)
+
+        if len(failed_uploads) == 0:
+            return True
+
+        for i in failed_uploads:
+            Helpers.print_error("Failure uploading patient " + i[1]['mrn'] +
+                                " on line " + str(i[0]))
+
+        return False
+
+    def __upload_files_from_list(self, list_of_files, start):
+        '''loops through passed list and inserts files to the datalake
+
+        This function loops through the list passed and insertes each file into the clients datalake
+        all errors and upload times are logged.
+        
+        Args:
+            list_of_files (list): the list of file data we wish to upload
+            start (time.time): the start time of the operation
+        Returns:
+            list: the list of files that did not get processed
+
+        '''
         header = list_of_files[0]
         failed_uploads = []
         modality_index = header.index('MODALITY')
@@ -119,14 +158,16 @@ class Client:
             if not result:
                 failed_uploads.append((row, arguments))
 
-        if len(failed_uploads) == 0:
-            return True
+            if result and self.client_uuid == 'indx-test-client-datalake':
+                finish = time.time()
+                upload_time = finish - start
+                self.__throughput_logger.log_text(
+                    str(row) + " (" + str(DataLakeGlobals.SIZE_OF_FILES) +
+                    " MB) files have been processed in " + str(upload_time) +
+                    "seconds",
+                    severity="INFO")
 
-        for i in failed_uploads:
-            Helpers.print_error("Failure uploading patient " + i[1]['mrn'] +
-                                " on line " + str(i[0]))
-
-        return False
+        return failed_uploads
 
     def upload_patient(self, patient_data):
         '''
@@ -198,7 +239,7 @@ class Client:
         # run the document classifier, check if modality matches predicted modality
         classified_modality = self.__document_classifier_operations(
             arguments['mrn'], arguments['file_path'])
-        if not classified_modality:
+        if not classified_modality or classified_modality is None:
             classified_modality = 'Failed To Classify'
             warnings.warn("Request to document classifier failed.")
             self.__client_ops_logger.log_text(
