@@ -6,7 +6,7 @@
 from indxdatalaketools.GoogleClientWrappers import SecretManager
 from indxdatalaketools import Helpers
 
-PROPERTIES_DB_URL = 'https://properties-db-api-gate-27i5vb12.uc.gateway.dev/'
+PROPERTIES_DB_URL = 'https://properties.indx.acuityeyegroup.dev/'
 APPLICATION_JSON = "application/json"
 
 
@@ -45,7 +45,6 @@ class Client:
             # do not need to include non enabled property lists
             if 'enabled' in attributes and attributes['enabled']:
                 lists[attributes["list-name"]] = property_list["id"]
-
         return lists
 
     def get_modalities(self):
